@@ -2,9 +2,9 @@
  * 
  * scantwo_mr.h
  *
- * copyright (c) 2001-2, Karl W Broman, Johns Hopkins University
+ * copyright (c) 2001-6, Karl W Broman, Johns Hopkins University
  *
- * last modified Oct, 2002
+ * last modified Oct, 2006
  * first written Nov, 2001
  *
  * Licensed under the GNU General Public License version 2 (June, 1991)
@@ -98,7 +98,7 @@ void R_scantwo_2chr_mr(int *n_ind, int *n_pos1, int *n_pos2,
 		       double *addcov, int *n_addcov, 
 		       double *intcov, int *n_intcov, 
 		       double *pheno, double *weights,
-		       double *result_full, double *result_int);
+		       double *result_full, double *result_add);
 
 /**********************************************************************
  * 
@@ -140,8 +140,8 @@ void R_scantwo_2chr_mr(int *n_ind, int *n_pos1, int *n_pos2,
  *              containing the joint LODs
  *              Note: indexed as Result[pos2][pos1]
  *
- * Result_int   Result matrix of size [n_pos2 x n_pos1] 
- *              containing the LODs testing interactions
+ * Result_add   Result matrix of size [n_pos2 x n_pos1] 
+ *              containing the LODs for add've models
  *              also indexed as Result[pos2][pos1]
  *
  **********************************************************************/
@@ -151,6 +151,6 @@ void scantwo_2chr_mr(int n_ind, int n_pos1, int n_pos2, int n_gen1,
 		     double **Addcov, int n_addcov, 
 		     double **Intcov, int n_intcov, double *pheno, 
 		     double *weights,
-		     double **Result_full, double **Result_int);
+		     double **Result_full, double **Result_add);
 
 /* end of scantwo_mr.h */
